@@ -187,7 +187,7 @@ IncomingDataQueue::takeInDataPacket(void)
     unsigned char* buffer = new unsigned char[nextSize];
     int32 rtn = (int32)recvData(buffer,nextSize,network_address,transport_port);
     if ( (rtn < 0) || ((uint32)rtn > getMaxRecvPacketSize()) ){
-        delete buffer;
+        delete [] buffer;
         return 0;
     }
 
@@ -600,7 +600,8 @@ IncomingDataQueue::getWaiting(uint32 timestamp, const SyncSource* src)
             result = NULL;
         } else if ( recvFirst->getTimestamp() > timestamp ) {
             // there are only newer packets in the queue
-            l->setPrev(NULL);
+            if (l)
+                l->setPrev(NULL);
             result = NULL;
         } else {
             // (recvFirst->getTimestamp() == stamp) is true
